/* General */
html { font-family: "Lucida Sans Unicode", "Lucida Grande", sans-serif; font-size: 150%; }
h1, h2 { background-color: #b9cad9; }
h1 { padding-top: 1.5em; }
p, li, table { max-width: 40em; }
a:link, a:active, a:visited, a:hover { color: #00519a; }

/* Box */
table { background-color: #b9cad9; border: solid #00519a 2px; }

/* Footer */
ul.footer { background-color: #444; list-style-type: none; margin: 0; padding: 0; overflow: hidden; position: fixed; top: 0; width: 100%; } 
ul.footer li { float: left; border-right: 1px solid #bbb; }
ul.footer li a { display: block; color: #fff; text-align: center; padding: 1em 1em; text-decoration: none; }
ul.footer li a:hover { background-color: #000; }
ul.footer li a.active { background-color: #00519a; }
